==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/user/MapUserFederatedIdentityEntityFieldDelegate.java <==
package org.keycloak.models.map.user;
public class MapUserFederatedIdentityEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.user.MapUserFederatedIdentityEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> entityFieldDelegate;
    public MapUserFederatedIdentityEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getToken() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.TOKEN);
    }
    @SuppressWarnings("unchecked") @Override public void setToken(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.TOKEN, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIdentityProvider() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.IDENTITY_PROVIDER);
    }
    @SuppressWarnings("unchecked") @Override public void setIdentityProvider(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.IDENTITY_PROVIDER, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setUserName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_NAME, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/user/MapUserFederatedIdentityEntityFieldDelegate.java <==
package org.keycloak.models.map.user;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserFederatedIdentityEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.user.MapUserFederatedIdentityEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> entityFieldDelegate;
    public MapUserFederatedIdentityEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getToken() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.TOKEN);
    }
    @SuppressWarnings("unchecked") @Override public void setToken(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.TOKEN, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIdentityProvider() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.IDENTITY_PROVIDER);
    }
    @SuppressWarnings("unchecked") @Override public void setIdentityProvider(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.IDENTITY_PROVIDER, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setUserName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_NAME, p0);
    }
}
